==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/BUDGETGROUPITEMID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour BUDGETGROUPITEMID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="BUDGETGROUPITEMID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BUDGETGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ITEMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BUDGETGROUPITEMID_Type", propOrder = {
    "budgetgroupid",
    "itemid"
})
public class BUDGETGROUPITEMID_Type {

    @XmlElement(name = "BUDGETGROUPID", required = true)
    protected BUDGETGROUPID_Type budgetgroupid;
    @XmlElement(name = "ITEMID", required = true)
    protected ITEMID_Type itemid;

    /**
     * Obtient la valeur de la propriété budgetgroupid.
     * 
     * @return
     *     possible object is
     *     {@link BUDGETGROUPID_Type }
     *     
     */
    public BUDGETGROUPID_Type getBUDGETGROUPID() {
        return budgetgroupid;
    }

    /**
     * Définit la valeur de la propriété budgetgroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link BUDGETGROUPID_Type }
     *     
     */
    public void setBUDGETGROUPID(BUDGETGROUPID_Type value) {
        this.budgetgroupid = value;
    }

    /**
     * Obtient la valeur de la propriété itemid.
     * 
     * @return
     *     possible object is
     *     {@link ITEMID_Type }
     *     
     */
    public ITEMID_Type getITEMID() {
        return itemid;
    }

    /**
     * Définit la valeur de la propriété itemid.
     * 
     * @param value
     *     allowed object is
     *     {@link ITEMID_Type }
     *     
     */
    public void setITEMID(ITEMID_Type value) {
        this.itemid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/BUDGETGROUPITEMID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BUDGETGROUPITEMID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BUDGETGROUPITEMID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BUDGETGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ITEMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BUDGETGROUPITEMID_Type", propOrder = {
    "budgetgroupid",
    "itemid"
})
public class BUDGETGROUPITEMID_Type {

    @XmlElement(name = "BUDGETGROUPID", required = true)
    protected BUDGETGROUPID_Type budgetgroupid;
    @XmlElement(name = "ITEMID", required = true)
    protected ITEMID_Type itemid;

    /**
     * Gets the value of the budgetgroupid property.
     * 
     * @return
     *     possible object is
     *     {@link BUDGETGROUPID_Type }
     *     
     */
    public BUDGETGROUPID_Type getBUDGETGROUPID() {
        return budgetgroupid;
    }

    /**
     * Sets the value of the budgetgroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link BUDGETGROUPID_Type }
     *     
     */
    public void setBUDGETGROUPID(BUDGETGROUPID_Type value) {
        this.budgetgroupid = value;
    }

    /**
     * Gets the value of the itemid property.
     * 
     * @return
     *     possible object is
     *     {@link ITEMID_Type }
     *     
     */
    public ITEMID_Type getITEMID() {
        return itemid;
    }

    /**
     * Sets the value of the itemid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ITEMID_Type }
     *     
     */
    public void setITEMID(ITEMID_Type value) {
        this.itemid = value;
    }

}
